===============================
Static Django Migration Conflict Checker
===============================


.. image:: https://img.shields.io/pypi/v/django_migration_checker.svg
        :target: https://pypi.python.org/pypi/django_migration_checker

.. image:: https://img.shields.io/travis/rev112/django_migration_checker.svg
        :target: https://travis-ci.org/rev112/django_migration_checker

.. image:: https://readthedocs.org/projects/django-migration-checker/badge/?version=latest
        :target: https://django-migration-checker.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/rev112/django_migration_checker/shield.svg
     :target: https://pyup.io/repos/github/rev112/django_migration_checker/
     :alt: Updates


Python Boilerplate contains all the boilerplate you need to create a Python package.


* Free software: MIT license
* Documentation: https://django-migration-checker.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

